| Title: | CSU R Tutorials |
|---|---|
| Description: | This package contains learnr tutorials used to teach R for STAT 170 students. |
| Authors: | Isaac Quintanilla Salinas [aut, cre] (ORCID: <https://orcid.org/0000-0002-1137-4310>) |
| Maintainer: | Isaac Quintanilla Salinas <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.8 |
| Built: | 2026-05-14 09:17:25 UTC |
| Source: | https://github.com/inqs909/csustats |
A wrapper function to access the tutorial using the learnr package
access_tutorial(tutorial)access_tutorial(tutorial)
tutorial |
A character value contianing the name of the tutorial. |
Isaac Quintanilla Salinas
A function that lists all of the available tutorials in the "ucrstats" package
list_tutorials()list_tutorials()
A table containing a list of all the tutorials in the package
tutorialstutorials
A data frame
The string placed in the 'access_tutorial' function to access the tutorial
The topic the tutorial generally relates to
A brief description of what the tutorial will cover